powered by
Search for a player -- either exact match or using fixed regular expressions -- and return all penalties taken by or against this player as table.
penaltyPrint(player, goalkeeper = TRUE, exact = TRUE, pendat, includeMisses = TRUE)
Character vector of length 1 which contains the full name of a player in pendat or a part thereof.
pendat
Boolean, specifies whether player is searched for among goalkeepers (TRUE) or penalty takers (FALSE).
player
Boolean, specifies whether to look for an exact match. If set to FALSE, grep(player, fixed = TRUE) is used to search for the player.
grep(player, fixed = TRUE)
Name of a data set containing the penalties. The data set needs to follow the format of penalties.
penalties
Boolean, indicates whether to include penalties that missed the goal without the goalkeeper actively saving the ball.
Returns a data.frame that is a subset of pendat.
data.frame
penaltyPlot
# NOT RUN { data(penalties) penaltyPrint('Illgner, Bodo', pendat = penalties) penaltyPrint('Illgner', exact = FALSE, pendat = penalties) # }
Run the code above in your browser using DataLab